#include <iostream>
using namespace std;

#define LEFT -1
#define RIGHT 1
#define CHANGEDIR(d) ( d = (d == RIGHT ? LEFT : RIGHT) )
#define ABS(a) ( a < 0 ? -1 : a )
#define MAX2(a,b) ( a > b ? a : b )

struct Ant
{
	int pos, start;
	int dir; // -1, 1
	bool dead;
	int steps;
	bool moved;

	Ant ()
	{
		dir = LEFT;
		pos = -1;
		start = -1;
	}
	
	Ant(int p, char d)
	{
		dir = (d == 'R' ? RIGHT : LEFT);
		pos = p;
		start = p;
		dead = false;
		steps = 0;
		moved = false;
	}
	
	void set_dead(int edge)
	{
		if ( pos < 0 || pos > edge )
			dead = true;
	}
	
	void move( int edge )
	{
		if ( dead ) return;
		
		pos += dir;
		steps++;
		moved = true;
		
		set_dead(edge);
	}
	
	int meeting ( Ant & ant )
	{
		if ( this->dead || ant.dead ) return 0;
		
		bool against = false;
		
		if ( pos > ant.pos && dir == LEFT && ant.dir == RIGHT )
			against = true;
		if ( pos < ant.pos && dir == RIGHT && ant.dir == LEFT )
			against = true;
		
		if ( against )
		{
			if ( pos+dir == ant.pos+ant.dir ) 
			{
				return 1;
			}
			else
			if ( ABS(pos - ant.pos) == 1 )
			{
				return 2;
			}
			
			return 0;
		}
		
		return 0;
	}

	void print()
	{
		cout << "Pos: " << pos << ", Dir: " << dir << "(" << start << ")\n";
		cout << "\tDEAD: " << dead << endl;
	}	
};


void copy_to ( Ant * a, Ant * b, int count )
{
	for ( int i = 0; i < count; i++ )
		a[i] = b[i];
}

int main ()
{

	while ( cin )
	{
		int length, count;
		cin >> length >> count;
		
		cout << "Len: " << length << " Count: " << count << endl;
		Ant ants[count];
		Ant atmp[count];
		
		for ( int i = 0; i < count; i++ )
		{
			int pos;
			char d;
			cin >> pos >> d;

			ants[i] = Ant(pos, d);
		}
		copy_to ( atmp, ants, count );

		cout << "Ants\n";		
		for ( int i = 0; i < count; i++ )
			ants[i].print();
		cout << endl;
			
		cout << "Simulation:\n";
		int allsteps = 0;
		
		while(1)
		{
			allsteps++;
			
			int deads = 0;
			
			for ( int i = 0; i < count; i++ ) ants[i].moved = false;
			
			for ( int i = 0; i < count; i++ )
			{
				int met = -1;							
				int metstyle = 0;
				
				for ( int j = i+1; j < count; j++ )
				{
					if ( ants[i].meeting(ants[j]) )
					{
						met = j;
						metstyle = ants[i].meeting(ants[j]);
						
						cout << "Met " << ants[i].start << " and " << ants[j].start << "\n";
						cout << "style: " << metstyle << "\n";
						break;
					}
				}
				
				if ( met == -1 )
					atmp[i].move(length);
				else
				{
					if ( metstyle == 1 )
					{
						atmp[i].pos += atmp[i].dir;
						atmp[met].pos = atmp[i].pos;
						CHANGEDIR(atmp[i].dir);
						CHANGEDIR(atmp[met].dir);

						atmp[i].set_dead(length);
						atmp[met].set_dead(length);
					}
					else
					if ( metstyle == 2 )
					{
						CHANGEDIR(atmp[i].dir);
						CHANGEDIR(atmp[met].dir);
					}
				}
				
				if ( atmp[i].dead )
				{
				 	deads ++;
				}
			}
			
			
			copy_to ( ants, atmp, count );
			
			
			cout << "Deads: " << deads << endl;
			cout << "Ants\n";
			for ( int i = 0; i < count; i++ )
				ants[i].print();
			cout << endl;
			
			
			
			if ( deads == count-2 )
			{
				int k,l;
				k = l = -1;
				
				for ( int i = 0; i < count; i++ )
					if ( ! ants[i].dead )
					{
						if ( k == -1 ) k = i;
						else l = i;
					}
						
				int maxsteps = MAX2(ants[k].steps, ants[l].steps);
				cout << "The last ant will fall down in " << allsteps << " seconds - ";
				cout << "started at " << ants[k].start << " and " << ants[l].start << ".\n";
				
				break;
			}
		}

		char c;
		cin >> c;			
	}

	return 0;
}
